function [result] = multisvm(train_matrix,group,test_shape)
%Models a given training set with a corresponding group vector and 
%classifies a given test set using an SVM classifier according to a 
%one vs. all relation. 
%
%This code was written by Cody Neuburger cneuburg@fau.edu
%Florida Atlantic University, Florida USA
%This code was adapted and cleaned from Anand Mishra's multisvm function
%found at http://www.mathworks.com/matlabcentral/fileexchange/33170-multi-class-support-vector-machine/

u=unique(group);
numClasses=length(u);
result = zeros(length(test_shape(:,1)),1);

%build models
for k=1:numClasses
    %Vectorized statement that binarizes Group
    %where 1 is the current class and 0 is all other classes
    G1vAll=(group==u(k));
    models(k) = svmtrain(train_matrix,G1vAll);
end

%classify test cases
for j=1:size(test_shape,1)
    for k=1:numClasses
        if(svmclassify(models(k),test_shape(j,:))) 
            break;
        end
    end
    result(j) = k;
end